==> assertive_0.3-1.tar.gz: assertive/R/exports-strings.R <==
# Deprecated is_not_missing_nor_empty_character included here temporarily.

# From assertive.strings is-empty-character.R, assert-is-empty-character.R

#' Does the input contain empty or missing strings?
#' 
#' See \code{\link[assertive.strings]{is_empty_character}}.
#' @name is_empty_character
#' @aliases is_non_empty_character is_missing_or_empty_character is_non_missing_nor_empty_character is_not_missing_nor_empty_character is_an_empty_string is_a_non_empty_string is_a_missing_or_empty_string is_a_non_missing_nor_empty_string assert_all_are_empty_character assert_any_are_empty_character assert_all_are_non_empty_character assert_any_are_non_empty_character assert_all_are_missing_or_empty_character assert_any_are_non_empty_character assert_all_are_missing_or_empty_character assert_any_are_missing_or_empty_character assert_all_are_non_missing_nor_empty_character assert_any_are_non_missing_nor_empty_character assert_is_an_empty_string assert_is_a_non_empty_string assert_is_a_missing_or_empty_string assert_is_a_non_missing_nor_empty_string
#' @export is_empty_character
#' @export is_non_empty_character 
#' @export is_missing_or_empty_character
#' @export is_non_missing_nor_empty_character
#' @export is_not_missing_nor_empty_character
#' @export is_an_empty_string
#' @export is_a_non_empty_string
#' @export is_a_missing_or_empty_string
#' @export is_a_non_missing_nor_empty_string
#' @export assert_all_are_empty_character
#' @export assert_any_are_empty_character
#' @export assert_all_are_non_empty_character
#' @export assert_any_are_non_empty_character
#' @export assert_all_are_missing_or_empty_character
#' @export assert_any_are_missing_or_empty_character
#' @export assert_all_are_non_missing_nor_empty_character
#' @export assert_any_are_non_missing_nor_empty_character
#' @export assert_is_an_empty_string
#' @export assert_is_a_non_empty_string
#' @export assert_is_a_missing_or_empty_string
#' @export assert_is_a_non_missing_nor_empty_string
NULL

# From assertive.strings is-special-string.R, assert-is-special-string.R

#' Does the string contain a number?
#'  
#' See \code{\link[assertive.strings]{is_numeric_string}}.
#' @name is_numeric_string
#' @aliases assert_all_are_numeric_strings assert_any_are_numeric_strings
#' @export is_numeric_string
#' @export assert_all_are_numeric_strings
#' @export assert_any_are_numeric_strings
NULL

#' Is the input a single character?
#'  
#' See \code{\link[assertive.strings]{is_single_character}}.
#' @name is_single_character
#' @aliases assert_all_are_single_characters assert_any_are_single_characters
#' @export is_single_character
#' @export assert_all_are_single_characters
#' @export assert_any_are_single_characters
NULL

# From assertive.strings utils.R

#' Convert a character vector to a list of integer vectors
#'  
#' See \code{\link[assertive.strings]{character_to_list_of_integer_vectors}}.
#' @name character_to_list_of_integer_vectors
#' @export character_to_list_of_integer_vectors
NULL

==> assertive_0.3-3.tar.gz: assertive/R/exports-strings.R <==
# Deprecated is_not_missing_nor_empty_character included here temporarily.

# From assertive.strings is-empty-character.R, assert-is-empty-character.R

#' Does the input contain empty or missing strings?
#' 
#' See \code{\link[assertive.strings]{is_empty_character}}.
#' @name is_empty_character
#' @aliases is_non_empty_character is_missing_or_empty_character is_non_missing_nor_empty_character is_not_missing_nor_empty_character is_an_empty_string is_a_non_empty_string is_a_missing_or_empty_string is_a_non_missing_nor_empty_string assert_all_are_empty_character assert_any_are_empty_character assert_all_are_non_empty_character assert_any_are_non_empty_character assert_all_are_missing_or_empty_character assert_any_are_non_empty_character assert_all_are_missing_or_empty_character assert_any_are_missing_or_empty_character assert_all_are_non_missing_nor_empty_character assert_any_are_non_missing_nor_empty_character assert_is_an_empty_string assert_is_a_non_empty_string assert_is_a_missing_or_empty_string assert_is_a_non_missing_nor_empty_string assert_all_strings_are_not_missing_nor_empty assert_any_strings_are_not_missing_nor_empty
#' @export is_empty_character
#' @export is_non_empty_character 
#' @export is_missing_or_empty_character
#' @export is_non_missing_nor_empty_character
#' @export is_not_missing_nor_empty_character
#' @export is_an_empty_string
#' @export is_a_non_empty_string
#' @export is_a_missing_or_empty_string
#' @export is_a_non_missing_nor_empty_string
#' @export assert_all_are_empty_character
#' @export assert_any_are_empty_character
#' @export assert_all_are_non_empty_character
#' @export assert_any_are_non_empty_character
#' @export assert_all_are_missing_or_empty_character
#' @export assert_any_are_missing_or_empty_character
#' @export assert_all_are_non_missing_nor_empty_character
#' @export assert_any_are_non_missing_nor_empty_character
#' @export assert_is_an_empty_string
#' @export assert_is_a_non_empty_string
#' @export assert_is_a_missing_or_empty_string
#' @export assert_is_a_non_missing_nor_empty_string
#' @export assert_all_strings_are_not_missing_nor_empty
#' @export assert_any_strings_are_not_missing_nor_empty
NULL

# From assertive.strings is-special-string.R, assert-is-special-string.R

#' Does the string contain a number?
#'  
#' See \code{\link[assertive.strings]{is_numeric_string}}.
#' @name is_numeric_string
#' @aliases is_logical_string assert_all_are_numeric_strings assert_any_are_numeric_strings assert_all_are_logical_strings assert_any_are_logical_strings
#' @export is_numeric_string
#' @export is_logical_string
#' @export assert_all_are_numeric_strings
#' @export assert_any_are_numeric_strings
#' @export assert_all_are_logical_strings
#' @export assert_any_are_logical_strings
NULL

#' Is the input a single character?
#'  
#' See \code{\link[assertive.strings]{is_single_character}}.
#' @name is_single_character
#' @aliases assert_all_are_single_characters assert_any_are_single_characters
#' @export is_single_character
#' @export assert_all_are_single_characters
#' @export assert_any_are_single_characters
NULL

# From assertive.strings utils.R

#' Convert a character vector to a list of integer vectors
#'  
#' See \code{\link[assertive.strings]{character_to_list_of_integer_vectors}}.
#' @name character_to_list_of_integer_vectors
#' @export character_to_list_of_integer_vectors
NULL
